#########
platforms
#########

ROMSearch can work for a number of platforms, and the config for each is stored in a separate configuration file.

Syntax: ::

    group: ["Redump", "No-Intro"]    # The group for these files. Currently either "Redump" or "No-Intro
    dir: [dir]                       # The remote dir for rclone. This is usually something like [group]/[platform]
    unzip: true                      # OPTIONAL. Whether to unzip files when moving. Defaults to false
    additional_dirs:                 # OPTIONAL. Occasionally, files may need to be pulled from other remote directories.
      [additional_dir]: [dir]        #           These can be specified here

    ra_id: [id]                      # OPTIONAL. The RetroAchievements console ID, from their API_GetConsoleIDs
    ra_hash_method: ["md5", "custom] # OPTIONAL. The RetroAchievements hash method. Supports "md5" for now

Nintendo - Game Boy
===================

.. literalinclude:: ../../romsearch/configs/platforms/Nintendo - Game Boy.yml

Nintendo - Game Boy Color
=========================

.. literalinclude:: ../../romsearch/configs/platforms/Nintendo - Game Boy Color.yml

Nintendo - GameCube
===================

.. literalinclude:: ../../romsearch/configs/platforms/Nintendo - GameCube.yml

Nintendo - Super Nintendo Entertainment System
==============================================

.. literalinclude:: ../../romsearch/configs/platforms/Nintendo - Super Nintendo Entertainment System.yml

Sony - PlayStation
==================

.. literalinclude:: ../../romsearch/configs/platforms/Sony - PlayStation.yml